<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Configuration du plugin OSC</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Configuration des univers</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Port d&apos;entrée</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Addresse IP de sortie</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Port de sortie</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="90"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="122"/>
        <source>Channel number calculator</source>
        <translation>Calculateur de numéro de canal</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="130"/>
        <source>OSC path</source>
        <translation>Chemin OSC</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="140"/>
        <source>Channel number</source>
        <translation>Numéro de canal</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="88"/>
        <source>Inputs</source>
        <translation>Entrées</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="94"/>
        <source>Outputs</source>
        <translation>Sorties</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>Invalid IP</source>
        <translation>IP invalide</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 n&apos;est pas une IP valide.
Veuillez la corriger avant de valider.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="96"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Ce plugin offre le support des périphériques supportant le protocole OSC.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <location filename="oscplugin.cpp" line="280"/>
        <source>Status: Not open</source>
        <translation>Status : fermé</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="150"/>
        <location filename="oscplugin.cpp" line="283"/>
        <source>Status: Open</source>
        <translation>Status : ouvert</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="152"/>
        <source>Packets sent: </source>
        <translation>Paquets envoyés : </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="285"/>
        <source>Packets received: </source>
        <translation>Paquets reçus : </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="143"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Input</source>
        <translation>Entrée</translation>
    </message>
</context>
</TS>
